==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-lt-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Lithuanian (http://www.transifex.com/tine20/tine20/language/lt/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: lt\nPlural-Forms: nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  ""
 ,""
 ,""
 ,""

]
, "Groups"
: "Grupės"

, "Roles"
: "Vaidmenys"

, "Applications"
: "Moduliai"

, "Containers"
: ""

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: "Kompiuteriai"

, "Access Log, Access Logs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: ""

, "Refresh"
: ""

, "Name"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  ""
 ,""
 ,""
 ,""

]
, "Application, Applications"
: [
  ""
 ,""
 ,""
 ,""

]
, "Config, Configs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Configs"
: ""

, "Please wait"
: ""

, "Updating Memberships"
: ""

, "Failed"
: ""

, "Could not save group."
: ""

, "Errors"
: ""

, "Please fix the errors noted."
: ""

, "Group Name"
: ""

, "Description"
: ""

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Group Members"
: ""

, "Transferring {0}..."
: ""

, "Add new group"
: ""

, "Edit Group \"{0}\""
: ""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "Nustatymai"

, "enable application"
: "įjungti programėlę"

, "disable application"
: "išjungti programėlę"

, "settings"
: "nustatymai"

, "Search:"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: ""

, "Order"
: ""

, "Status"
: ""

, "Version"
: ""

, "Confirm"
: ""

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: ""

, "IP Address"
: ""

, "Login Time"
: ""

, "Logout Time"
: ""

, "Client Type"
: ""

, "Session ID"
: ""

, "Login Name"
: ""

, "Result"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: ""

, "ambiguous username"
: ""

, "user not found"
: ""

, "failure"
: ""

, "success"
: ""

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: ""

, "Role Name"
: ""

, "Role"
: ""

, "Add New Role"
: ""

, "Edit Role \"{0}\""
: ""

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Color"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""
 ,""
 ,""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: ""

, "First name"
: ""

, "Email"
: ""

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: ""

, "Last login from"
: ""

, "Password changed"
: ""

, "Expires"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""
 ,""
 ,""
 ,""

]
, "Email User, Email Users"
: [
  ""
 ,""
 ,""
 ,""

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Logon Time"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "Logoff Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: ""

, "Add an alias address..."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: ""

, "Add a forward address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "Password"
: ""

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "valdyti prisijungimo įrašus"

, "delete access log entries"
: "ištrinti prisijungimo įrašų informaciją"

, "manage accounts"
: "valdyti paskyras"

, "add and edit users and groups, add group members, change user passwords"
: "pridėti ir redaguoti vartotojus ir grupes, pridėti grupės narius, pakeisti vartotojų slaptažodžius"

, "manage applications"
: "valdyti programėles"

, "enable and disable applications, edit application settings"
: "įjungti ir išjungti programėles, redaguoti programėles nustatymus"

, "manage roles"
: "valdyti roles"

, "add and edit roles, add new members to roles, add application rights to roles"
: "pridėti ir redaguoti funkcijas, priskirti naujus narius funkcijoms, priskirti programėlėms teises"

, "manage shared tags"
: ""

, "add, delete and edit shared tags"
: ""

, "manage computers"
: ""

, "add, delete and edit (samba) computers"
: ""

, "manage containers"
: ""

, "add, delete and edit containers and manage container grants"
: ""

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: ""

, "view access log list"
: ""

, "view accounts"
: ""

, "view accounts list and details"
: ""

, "view applications"
: ""

, "view applications list and details"
: ""

, "view roles"
: ""

, "view roles list and details"
: ""

, "view computers"
: ""

, "view computers list and details"
: ""

, "view containers"
: ""

, "view personal and shared containers"
: ""

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: ""

, "Access Log"
: ""

, "Computer"
: ""

, "Group"
: ""

, "Application"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Samba User"
: ""

, "Email User"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-lt-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Lithuanian (http://www.transifex.com/tine20/tine20/language/lt/)\nLanguage: lt\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "Nustatymai"

, "Search:"
: ""

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: ""

, "Order"
: ""

, "Name"
: ""

, "Status"
: ""

, "Version"
: ""

, "Confirm"
: ""

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Failed"
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: ""

, "E-mail"
: ""

, "Description"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: ""

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""
 ,""
 ,""
 ,""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""
 ,""
 ,""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""
 ,""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Color"
: ""

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Updating Memberships"
: ""

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: ""

, "Role Name"
: ""

, "Role"
: ""

, "Add New Role"
: ""

, "Edit Role \"{0}\""
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Access Log, Access Logs"
: [
  ""
 ,""
 ,""
 ,""

]
, "Groups"
: "Grupės"

, "Applications"
: "Moduliai"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Login Time"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "Logout Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "First name"
: ""

, "Last name"
: ""

, "Login name"
: ""

, "Password"
: ""

, "OpenID"
: ""

, "enabled"
: ""

, "disabled"
: ""

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: ""

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Last login at"
: ""

, "don't know"
: ""

, "Last login from"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "User, Users"
: [
  ""
 ,""
 ,""
 ,""

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""
 ,""
 ,""
 ,""

]
, "Email User, Email Users"
: [
  ""
 ,""
 ,""
 ,""

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: ""

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Vaidmenys"

, "Containers"
: ""

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: "Kompiuteriai"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: ""

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: ""

, "Client Type"
: ""

, "Session ID"
: ""

, "Login Name"
: ""

, "Result"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: ""

, "ambiguous username"
: ""

, "user not found"
: ""

, "failure"
: ""

, "success"
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""












, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: ""

, "Samba User"
: ""

, "Email User"
: ""

, "Container"
: ""

, "Computer"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
